@@ -1,10 +1,8 @@
-#include <QtGui>
-#include <QtDBus>
+#include <QApplication>
 #include "mainwindow.h"
 
 int main(int argc, char *argv[])
 {
-	qDebug() << "Version 0.2-broken broken";
 	QApplication app(argc, argv);
 	mainWindow window;
 	window.show();
