@@ -11,14 +11,13 @@ class mainWindow : public QMainWindow
 public:
 	mainWindow();
 	void closeEvent(QCloseEvent *event);
-public slots:
+private slots:
 	void autoOrient();
 	void help();
-	void noSave();
+	//void noSave();
 	void openFile();
 	void newList();
 private:
-	QLayout *layout;
 	QScrollArea *portrait;
 	QPlainTextEdit *landscape;
 	void goLandscape(void);
